from setuptools import setup

setup(
    name='DE_LogEventos',
    version='0.0.7',
    packages=[''],
    url='https://github.com/almirjgomes/DE_LogEventos.git',
    license='MIT',
    author='Almir J Gomes',
    author_email='almir.jg@hotmail.com',
    description='LogEventos',
    long_description="Incluida condição de quebra de linha para a impressao na tela 'screen' "
)
